==> Products.TinyMCE-1.1rc12.zip: Products.TinyMCE-1.1rc12/Products/TinyMCE/skins/tinymce/langs/ca.js <==
tinyMCE.addI18n({ca:{
common:{
edit_confirm:"Voleu utilitzar el mode WYSIWYG?",
apply:"Aplica",
insert:"Insereix",
update:"Actualitza",
cancel:"Cancel\u00B7la",
close:"Tanca",
browse:"Explora",
class_name:"Classe",
not_set:"-- No definit --",
clipboard_msg:"Copia/Retalla/Enganxa no es troba disponible al Mozilla ni al Firefox.\nVoleu m\u00E9s informaci\u00F3 sobre aquesta q\u00FCesti\u00F3?",
clipboard_no_support:"El vostre navegador actualment no ho admet, utilitzeu les dreceres de teclat.",
popup_blocked:"El bloqueig de finestres emergents ha inhabilitat una finestra que proporciona funcionalitat a l\'aplicaci\u00F3. Cal que desactiveu el bloqueig de finestres emergents en aquest lloc per tal de poder utilitzar de forma completa aquesta eina.",
invalid_data:"Error: heu introdu\u00EFt valors no v\u00E0lids, els marcats en vermell.",
more_colors:"M\u00E9s colors"
},
contextmenu:{
align:"Alineaci\u00F3",
left:"Esquerra",
center:"Centre",
right:"Dreta",
full:"Justificat"
},
insertdatetime:{
date_fmt:"%d-%m-%Y",
time_fmt:"%H:%M:%S",
insertdate_desc:"Insereix la data",
inserttime_desc:"Insereix l\'hora",
months_long:"Jgener,febrer,mar\u00E7,abril,maig,juny,juliol,agost,setembre,octubre,novembre,desembre",
months_short:"gen.,febr.,mar\u00E7,abr.,maig,juny,jul.,ag.,set.,oct.,nov.,des.",
day_long:"diumenge,dilluns,dimarts,dimecres,dijous,divendres,dissabte,diumenge",
day_short:"dg.,dl.,dt.,dc.,dj.,dv.,ds.,dg."
},
print:{
print_desc:"Imprimeix"
},
preview:{
preview_desc:"Previsualitzaci\u00F3"
},
directionality:{
ltr_desc:"Direcci\u00F3 esquerra a dreta",
rtl_desc:"Direcci\u00F3 dreta a esquerra"
},
layer:{
insertlayer_desc:"Insereix una nova capa",
forward_desc:"Mou endavant",
backward_desc:"Mou endarrera",
absolute_desc:"Conmuta el posicionament absolut",
content:"Nova Capa..."
},
save:{
save_desc:"Desa",
cancel_desc:"Cancel\u00B7la tots els canvis"
},
nonbreaking:{
nonbreaking_desc:"Insereix un car\u00E0cter espai en blanc"
},
iespell:{
iespell_desc:"Executa la correcci\u00F3 ortogr\u00E0fica",
download:"no he detectat l\'ieSpell. Voleu instal\u00B7lar-ho?"
},
advhr:{
advhr_desc:"Filet horitzontal"
},
emotions:{
emotions_desc:"Emoticones"
},
searchreplace:{
search_desc:"Cerca",
replace_desc:"Cerca/Reempla\u00E7a"
},
advimage:{
image_desc:"Insereix/edita imatge"
},
advlink:{
link_desc:"Insert/edit link"
},
xhtmlxtras:{
cite_desc:"Citaci\u00F3",
abbr_desc:"Abreviaci\u00F3",
acronym_desc:"Acr\u00F2nim",
del_desc:"Eliminaci\u00F3",
ins_desc:"Inserci\u00F3",
attribs_desc:"Insereix/edita atributs"
},
style:{
desc:"Edita l\'estil CSS"
},
paste:{
paste_text_desc:"Enganxa com a text pla",
paste_word_desc:"Enganxa des del Word",
selectall_desc:"Selecciona-ho tot",
plaintext_mode_sticky:"Paste is now in plain text mode. Click again to toggle back to regular paste mode. After you paste something you will be returned to regular paste mode.",
plaintext_mode:"Paste is now in plain text mode. Click again to toggle back to regular paste mode."
},
paste_dlg:{
text_title:"Amb el teclat utilitzeu CTRL+V per a enganxar el text dins la finestra.",
text_linebreaks:"Conserva els salts de l\u00EDnia",
word_title:"Amb el teclat utilitzeu CTRL+V per a enganxar el text dins la finestra."
},
table:{
desc:"Insereix una nova taula",
row_before_desc:"Insereix una fila abans",
row_after_desc:"Insereix una fila despr\u00E9s",
delete_row_desc:"Elimina la fila",
col_before_desc:"Insereix una columna abans",
col_after_desc:"Insereix una columna despr\u00E9s",
delete_col_desc:"Elimina la columna",
split_cells_desc:"Divideix les cel\u00B7les fusionades",
merge_cells_desc:"Fusiona les cel\u00B7les",
row_desc:"Propietats de la fila",
cell_desc:"Propietats de la cel\u00B7la",
props_desc:"Propietats de la taula",
paste_row_before_desc:"Enganxa la fila abans",
paste_row_after_desc:"Enganxa la fila despr\u00E9s",
cut_row_desc:"Retalla la fila",
copy_row_desc:"Copia la fila",
del:"Elimina la taula",
row:"Fila",
col:"Columna",
cell:"Cel\u00B7la"
},
autosave:{
unload_msg:"Els canvis que heu fet es perdran si navegueu a fora d\'aquesta p\u00E0gina.",
restore_content:"Restore auto-saved content.",
warning_message:"If you restore the saved content, you will lose all the content that is currently in the editor.\n\nAre you sure you want to restore the saved content?."
},
fullscreen:{
desc:"Commuta a mode de pantalla completa"
},
media:{
desc:"Insereix / edita multim\u00E8dia incrustat",
edit:"Edita multim\u00E8dia incrustat"
},
fullpage:{
desc:"Propietats del document"
},
template:{
desc:"Insereix un contingut predefinit"
},
visualchars:{
desc:"Activa/desactiva els car\u00E0cters de control visual."
},
spellchecker:{
desc:"Corrector ortogr\u00E0fic",
menu:"Configuraci\u00F3 del corrector",
ignore_word:"Ignora el mot",
ignore_words:"Ignora\'ls tots",
langs:"Idiomes",
wait:"Espereu...",
sug:"Suggeriments",
no_sug:"Cap suggeriment",
no_mpell:"No s\'ha trobat cap falta d\'ortografia."
},
pagebreak:{
desc:"Insereix un salt de p\u00E0gina."
},
advlist:{
types:"Types",
def:"Default",
lower_alpha:"Lower alpha",
lower_greek:"Lower greek",
lower_roman:"Lower roman",
upper_alpha:"Upper alpha",
upper_roman:"Upper roman",
circle:"Circle",
disc:"Disc",
square:"Square"
}}});

==> Products.TinyMCE-1.2.5.zip: Products.TinyMCE-1.2.5/Products/TinyMCE/skins/tinymce/langs/ca.js <==
tinyMCE.addI18n({ca:{
common:{
edit_confirm:"Voleu utilitzar el mode WYSIWYG?",
apply:"Aplica",
insert:"Insereix",
update:"Actualitza",
cancel:"Cancel\u00B7la",
close:"Tanca",
browse:"Explora",
class_name:"Classe",
not_set:"-- No definit --",
clipboard_msg:"Copia/Retalla/Enganxa no es troba disponible al Mozilla ni al Firefox.\nVoleu m\u00E9s informaci\u00F3 sobre aquesta q\u00FCesti\u00F3?",
clipboard_no_support:"El vostre navegador actualment no ho admet, utilitzeu les dreceres de teclat.",
popup_blocked:"El bloqueig de finestres emergents ha inhabilitat una finestra que proporciona funcionalitat a l\'aplicaci\u00F3. Cal que desactiveu el bloqueig de finestres emergents en aquest lloc per tal de poder utilitzar de forma completa aquesta eina.",
invalid_data:"Error: heu introdu\u00EFt valors no v\u00E0lids, els marcats en vermell.",
more_colors:"M\u00E9s colors"
},
contextmenu:{
align:"Alineaci\u00F3",
left:"Esquerra",
center:"Centre",
right:"Dreta",
full:"Justificat"
},
insertdatetime:{
date_fmt:"%d-%m-%Y",
time_fmt:"%H:%M:%S",
insertdate_desc:"Insereix la data",
inserttime_desc:"Insereix l\'hora",
months_long:"Jgener,febrer,mar\u00E7,abril,maig,juny,juliol,agost,setembre,octubre,novembre,desembre",
months_short:"gen.,febr.,mar\u00E7,abr.,maig,juny,jul.,ag.,set.,oct.,nov.,des.",
day_long:"diumenge,dilluns,dimarts,dimecres,dijous,divendres,dissabte,diumenge",
day_short:"dg.,dl.,dt.,dc.,dj.,dv.,ds.,dg."
},
print:{
print_desc:"Imprimeix"
},
preview:{
preview_desc:"Previsualitzaci\u00F3"
},
directionality:{
ltr_desc:"Direcci\u00F3 esquerra a dreta",
rtl_desc:"Direcci\u00F3 dreta a esquerra"
},
layer:{
insertlayer_desc:"Insereix una nova capa",
forward_desc:"Mou endavant",
backward_desc:"Mou endarrera",
absolute_desc:"Conmuta el posicionament absolut",
content:"Nova Capa..."
},
save:{
save_desc:"Desa",
cancel_desc:"Cancel\u00B7la tots els canvis"
},
nonbreaking:{
nonbreaking_desc:"Insereix un car\u00E0cter espai en blanc"
},
iespell:{
iespell_desc:"Executa la correcci\u00F3 ortogr\u00E0fica",
download:"no he detectat l\'ieSpell. Voleu instal\u00B7lar-ho?"
},
advhr:{
advhr_desc:"Filet horitzontal"
},
emotions:{
emotions_desc:"Emoticones"
},
searchreplace:{
search_desc:"Cerca",
replace_desc:"Cerca/Reempla\u00E7a"
},
advimage:{
image_desc:"Insereix/edita imatge"
},
advlink:{
link_desc:"Insert/edit link"
},
xhtmlxtras:{
cite_desc:"Citaci\u00F3",
abbr_desc:"Abreviaci\u00F3",
acronym_desc:"Acr\u00F2nim",
del_desc:"Eliminaci\u00F3",
ins_desc:"Inserci\u00F3",
attribs_desc:"Insereix/edita atributs"
},
style:{
desc:"Edita l\'estil CSS"
},
paste:{
paste_text_desc:"Enganxa com a text pla",
paste_word_desc:"Enganxa des del Word",
selectall_desc:"Selecciona-ho tot",
plaintext_mode_sticky:"Enganxa est\u00E0 ara configurat en mode text pla. Clica de nou per tornar al mode normal d'enganxar. Despr\u00E9s d'enganxar quelcom ser\u00E0s retornat al mode normal d'enganxar.",
plaintext_mode:"Enganxa est\u00E0 ara configurat en mode text pla. Clica de nou per tornar al mode normal d'enganxar."
},
paste_dlg:{
text_title:"Amb el teclat utilitzeu CTRL+V per a enganxar el text dins la finestra.",
text_linebreaks:"Conserva els salts de l\u00EDnia",
word_title:"Amb el teclat utilitzeu CTRL+V per a enganxar el text dins la finestra."
},
table:{
desc:"Insereix una nova taula",
row_before_desc:"Insereix una fila abans",
row_after_desc:"Insereix una fila despr\u00E9s",
delete_row_desc:"Elimina la fila",
col_before_desc:"Insereix una columna abans",
col_after_desc:"Insereix una columna despr\u00E9s",
delete_col_desc:"Elimina la columna",
split_cells_desc:"Divideix les cel\u00B7les fusionades",
merge_cells_desc:"Fusiona les cel\u00B7les",
row_desc:"Propietats de la fila",
cell_desc:"Propietats de la cel\u00B7la",
props_desc:"Propietats de la taula",
paste_row_before_desc:"Enganxa la fila abans",
paste_row_after_desc:"Enganxa la fila despr\u00E9s",
cut_row_desc:"Retalla la fila",
copy_row_desc:"Copia la fila",
del:"Elimina la taula",
row:"Fila",
col:"Columna",
cell:"Cel\u00B7la"
},
autosave:{
unload_msg:"Els canvis que heu fet es perdran si navegueu a fora d\'aquesta p\u00E0gina.",
restore_content:"Restaura el contingut guardat autom\u00E0ticament.",
warning_message:"Si restaures el contingut guardat, perdr\u00E0s tot el contingut actual de l'editor. Est\u00E0s segur de voler continuar?"
},
fullscreen:{
desc:"Commuta a mode de pantalla completa"
},
media:{
desc:"Insereix / edita multim\u00E8dia incrustat",
edit:"Edita multim\u00E8dia incrustat"
},
fullpage:{
desc:"Propietats del document"
},
template:{
desc:"Insereix un contingut predefinit"
},
visualchars:{
desc:"Activa/desactiva els car\u00E0cters de control visual."
},
spellchecker:{
desc:"Corrector ortogr\u00E0fic",
menu:"Configuraci\u00F3 del corrector",
ignore_word:"Ignora el mot",
ignore_words:"Ignora\'ls tots",
langs:"Idiomes",
wait:"Espereu...",
sug:"Suggeriments",
no_sug:"Cap suggeriment",
no_mpell:"No s\'ha trobat cap falta d\'ortografia."
},
pagebreak:{
desc:"Insereix un salt de p\u00E0gina."
},
advlist:{
types:"Tipus",
def:"Per defecte",
lower_alpha:"Lletres",
lower_greek:"Lletres gregues (min\u00FAscules)",
lower_roman:"Nombres romans (min\u00FAscules)",
upper_alpha:"Lletres (maj\u00FAscules)",
upper_roman:"Nombres romans (maj\u00FAscules)",
circle:"Cercle",
disc:"Disc",
square:"Quadrat"
}}});
